@@ -1,7 +1,7 @@
 package Crypt::Password::Util;
 
-our $DATE = '2016-01-19'; # DATE
-our $VERSION = '0.13'; # VERSION
+our $DATE = '2016-01-20'; # DATE
+our $VERSION = '0.14'; # VERSION
 
 use 5.010001;
 use strict;
@@ -27,11 +27,19 @@ our %CRYPT_TYPES = (
     CRYPT => {
         summary => 'Traditional DES crypt',
         re => qr/\A
-                 (?P<salt>..)
+                 (?P<salt>$b64d {2} | \$\$) # $$ is not accepted as salt, but we see crypts using those in the wild
                  (?P<hash>$b64d {11}) \z/x,
         re_summary => '11 digit base64 characters',
         link => 'http://perldoc.perl.org/functions/crypt.html',
     },
+    'EXT-DES' => {
+        summary => 'Extended DES crypt',
+        re => qr/\A
+                 (?P<salt>_ $b64d {8} )
+                 (?P<hash>$b64d {11}) \z/x,
+        re_summary => 'underscore followed by 19 digit base64 characters',
+        link => 'https://en.wikipedia.org/wiki/Crypt_%28C%29#BSDi_extended_DES-based_scheme',
+    },
     SSHA256 => {
         summary => 'Salted SHA256, supported by glibc 2.7+',
         re => qr/\A
@@ -127,12 +135,27 @@ Crypt::Password::Util - Crypt password utilities
 
 =head1 VERSION
 
-This document describes version 0.13 of Crypt::Password::Util (from Perl distribution Crypt-Password-Util), released on 2016-01-19.
+This document describes version 0.14 of Crypt::Password::Util (from Perl distribution Crypt-Password-Util), released on 2016-01-20.
 
 =head1 SYNOPSIS
 
- use Crypt::Password::Util qw(crypt_type looks_like_crypt crypt);
+ use Crypt::Password::Util qw(
+     crypt
+     looks_like_crypt
+     crypt_type
+ );
 
+Generating crypted password:
+
+ say crypt('pass'); # automatically choose the appropriate type and salt
+
+Recognizing whether a string is a crypted password:
+
+ # return yes/no
+ say looks_like_crypt('62F4a6/89.12z');   # 1
+ say looks_like_crypt('foo');             # 0
+
+ # return the crypt type
  say crypt_type('62F4a6/89.12z');                    # CRYPT
  say crypt_type('$1$$...');                          # MD5-CRYPT
  say crypt_type('$apr1$4DdvgCFk$...');               # MD5-CRYPT
@@ -145,92 +168,97 @@ This document describes version 0.13 of Crypt::Password::Util (from Perl distrib
  # return detailed information
  my $res = crypt_type('$1$$oXYGukVGYa16SN.Pw5vNt/', 1);
  # => {type=>'MD5-CRYPT', header=>'$1$', salt=>'', hash=>'oXYGukVGYa16SN.Pw5vNt/'}
-
- say looks_like_crypt('62F4a6/89.12z');   # 1
- say looks_like_crypt('foo');             # 0
-
- say crypt('pass'); # automatically choose the appropriate type and salt
+ $res = crypt_type('foo', 1);
+ # => undef
 
 =head1 DESCRIPTION
 
-Crypt::Password::Util facilitates the generation and recognition of unix
-passwords as found in /etc/shadow on Unix/Linux systems and /etc/master.passwd
-on BSD systems. When using crypt(), it is possible several methods will be
-attempted before returning a result. This is done to insure that your system
-supports the selected hash type.
+Crypt::Password::Util provides routines to: 1) generate crypted password; 2)
+recognition of whether a string is a crypted password or not, and its crypt
+type.
+
+It recognizes several types of crypt methods:
+
+=over
+
+=item * BCRYPT
+
+Passphrase scheme based on Blowfish, designed by Niels Provos and David Mazieres for OpenBSD.
+
+Recognized by: $2$ or $2a$ header followed by cost, followed by 22 base64-digits salt and 31 digits hash.
+
+More info: L<https://www.usenix.org/legacy/event/usenix99/provos/provos_html/>
+
+=item * CRYPT
+
+Traditional DES crypt.
+
+Recognized by: 11 digit base64 characters.
+
+More info: L<http://perldoc.perl.org/functions/crypt.html>
+
+=item * EXT-DES
+
+Extended DES crypt.
+
+Recognized by: underscore followed by 19 digit base64 characters.
+
+More info: L<https://en.wikipedia.org/wiki/Crypt_%28C%29#BSDi_extended_DES-based_scheme>
+
+=item * MD5-CRYPT
+
+A baroque passphrase scheme based on MD5, designed by Poul-Henning Kamp and originally implemented in FreeBSD.
+
+Recognized by: $1$ or $apr1$ header.
+
+More info: L<http://static.usenix.org/event/usenix99/provos/provos_html/node10.html>
+
+=item * PLAIN-MD5
+
+Unsalted MD5 hash, popular with PHP web applications.
+
+Recognized by: 32 digits of hex characters.
+
+More info: L<http://en.wikipedia.org/wiki/MD5>
+
+=item * SSHA256
+
+Salted SHA256, supported by glibc 2.7+.
+
+Recognized by: $5$ header.
+
+More info: L<http://en.wikipedia.org/wiki/SHA-2>
+
+=item * SSHA512
+
+Salted SHA512, supported by glibc 2.7+.
+
+Recognized by: $6$ header.
+
+More info: L<http://en.wikipedia.org/wiki/SHA-2>
+
+=back
 
 =head1 FUNCTIONS
 
+=head2 looks_like_crypt($str) => bool
+
+Return true if C<$str> looks like a crypted password. If you want more
+information instead of just a yes/no, use C<crypt_type()>.
+
 =head2 crypt_type($str[, $detail]) => str|hash
 
 Return crypt type, or undef if C<$str> does not look like a crypted password.
 Currently known types:
 
- =over
- 
- =item * BCRYPT
- 
- Passphrase scheme based on Blowfish, designed by Niels Provos and David Mazieres for OpenBSD.
- 
- Recognized by: $2$ or $2a$ header followed by cost, followed by 22 base64-digits salt and 31 digits hash.
- 
- More info: L<https://www.usenix.org/legacy/event/usenix99/provos/provos_html/>
- 
- =item * CRYPT
- 
- Traditional DES crypt.
- 
- Recognized by: 11 digit base64 characters.
- 
- More info: L<http://perldoc.perl.org/functions/crypt.html>
- 
- =item * MD5-CRYPT
- 
- A baroque passphrase scheme based on MD5, designed by Poul-Henning Kamp and originally implemented in FreeBSD.
- 
- Recognized by: $1$ or $apr1$ header.
- 
- More info: L<http://static.usenix.org/event/usenix99/provos/provos_html/node10.html>
- 
- =item * PLAIN-MD5
- 
- Unsalted MD5 hash, popular with PHP web applications.
- 
- Recognized by: 32 digits of hex characters.
- 
- More info: L<http://en.wikipedia.org/wiki/MD5>
- 
- =item * SSHA256
- 
- Salted SHA256, supported by glibc 2.7+.
- 
- Recognized by: $5$ header.
- 
- More info: L<http://en.wikipedia.org/wiki/SHA-2>
- 
- =item * SSHA512
- 
- Salted SHA512, supported by glibc 2.7+.
- 
- Recognized by: $6$ header.
- 
- More info: L<http://en.wikipedia.org/wiki/SHA-2>
- 
- =back
-
 If C<$detail> is set to true, will return a hashref of information instead. This
 include C<type>, as well as the parsed header, salt, etc.
 
-=head2 looks_like_crypt($str) => BOOL
+=head2 crypt($str) => str
 
-Return true if C<$str> looks like a crypted password.
-
-=head2 crypt($str) => STR
-
-Like Perl's crypt(), but automatically choose the appropriate crypt type and
-random salt. Will first choose SSHA512 with 64-bit random salt. If not supported
-by system, fall back to MD5-CRYPT with 32-bit random salt. If that is not
-supported, fall back to CRYPT.
+Crypt password. Will first choose SSHA512 with 64-bit random salt. If not
+supported by system, fall back to MD5-CRYPT with 32-bit random salt. If that is
+not supported, fall back to CRYPT (traditional DES).
 
 =head1 HOMEPAGE
 
@@ -253,6 +281,13 @@ feature.
 L<Authen::Passphrase> which recognizes more encodings (but currently not SSHA256
 and SSHA512).
 
+L<Crypt::Bcrypt::Easy> to generate BCRYPT crypts.
+
+L<Crypt::PasswdMD5> to generate MD5-CRYPT crypts.
+
+L<Crypt::Password> which also provides a routine to compare a password with a
+crypted password.
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
